% Load the data (see README.md for a description of the data in this file)
load('figures_3_4');


%% Plot the error as a function of the number of dofs
figure
hold on;
for ind_order = 1:10;
    loglog(H1(ind_order,:),NonZeroEntries(ind_order,:))
    text(H1(ind_order,end)*1.1,NonZeroEntries(ind_order,end),num2str(ind_order),'FontSize',14)
end
hold off;
grid on; box on;
set_figure
set(gca, 'XMinorGrid', 'off', 'YMinorGrid', 'off');
set(gca,'Yscale','log','Xscale','log');
set(gca,'Ylim',[10^6,3*10^8]);
set(gca,'Xlim',[1.e-3,300]);
xlabel('Relative H^1 error (in %)');
ylabel('Number of non-zero entries');
title('(b)');


%% Plot the error as a function of the number of non-zero entries in the matrix
figure
hold on;
for ind_order = 1:10;
    loglog(H1(ind_order,:),Ndofs(ind_order,:))
    text(H1(ind_order,end)*1.1,Ndofs(ind_order,end),num2str(ind_order),'FontSize',14)
end
hold off;
grid on; box on;
set_figure
set(gca, 'XMinorGrid', 'off', 'YMinorGrid', 'off');
set(gca,'Yscale','log','Xscale','log')
set(gca,'Ylim',[10^4,2*10^6])
set(gca,'Xlim',[1.e-3,300]);
xlabel('Relative H^1 error (in %)');
ylabel('Number of degrees of freedom');
title('(a)');


%% Plot the error as a function of the factorisation time
figure
hold on;
for ind_order = 1:10;
    loglog(H1(ind_order,:),Time(ind_order,:))
    text(H1(ind_order,end)*1.1,Time(ind_order,end),num2str(ind_order),'FontSize',14)
end
hold off;
grid on; box on;
set_figure
set(gca, 'XMinorGrid', 'off', 'YMinorGrid', 'off');
set(gca,'Ylim',[1,1000])
set(gca,'Xlim',[1.e-3,300]);
set(gca,'Yscale','log','Xscale','log')
xlabel('Relative H^1 error (in %)');
ylabel('Time (in sec)','Fontsize',14);
grid on; box on;
title('(c)');


%% Plot the error as a function of the factorisation memory
figure
hold on;
for ind_order = 1:10;
    loglog(H1(ind_order,:),Memory(ind_order,:)/1000)
    text(H1(ind_order,end)*1.1,Memory(ind_order,end)/1000,num2str(ind_order),'FontSize',14)
end
hold off;
grid on; box on;
set_figure
set(gca, 'XMinorGrid', 'off', 'YMinorGrid', 'off');
set(gca,'Ylim',[0.1,60])
set(gca,'Xlim',[1.e-3,300]);
set(gca,'Yscale','log','Xscale','log')
xlabel('Relative H^1 error (in %)');
ylabel('Memory (in Gbytes)','Fontsize',14);
title('(d)');


%% Plot the error as a function of the element size
figure
hold on;
for ind_order = 1:10;
    loglog(H1(ind_order,:),1./Nelements(ind_order,:))
    text(H1(ind_order,end)*0.6,1./Nelements(ind_order,end),num2str(ind_order),'FontSize',14)
end
hold off;
grid on; box on;
set_figure
set(gca, 'XMinorGrid', 'off', 'YMinorGrid', 'off');
set(gca,'Yscale','log','Xscale','log')
set(gca,'Ylim',[0.01,1])
set(gca,'Xlim',[1.e-3,300]);
xlabel('Relative H^1 error (in %)');
ylabel('Element size h','Fontsize',14);
